WechatOpenCustomerServiceChatResp class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

WechatOpenCustomerServiceChatResp({required int errorCode, String? errorMsg})
const
WechatOpenCustomerServiceChatResp.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → int
错误码
finalinherited
errorMsg → String?
错误提示字符串
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isCancelled → bool
no setterinherited
isSuccessful → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited