MethodChannelWechatKit class

An implementation of WechatKitPlatform that uses method channels.

Inheritance

Constructors

MethodChannelWechatKit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth({required List<String> scope, String? state, int type = WechatAuthType.kNormal}) → Future<void>
授权登录
override
handleInitialWXReq() → Future<void>
微信回调 - 冷启
override
isInstalled() → Future<bool>
检测微信是否已安装
override
isSupportApi() → Future<bool>
判断当前微信的版本是否支持OpenApi
override
isSupportStateApi() → Future<bool>
判断当前微信的版本是否支持分享微信状态功能
override
launchMiniProgram({required String userName, String? path, int type = WechatMiniProgram.kRelease}) → Future<void>
打开小程序
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBusinessView({required String businessType, String? query, String? extInfo}) → Future<void>
调起支付分
override
openBusinessWebview({required int businessType, Map<String, String>? resultInfo}) → Future<void>
APP纯签约
override
openCustomerServiceChat({required String corpId, required String url}) → Future<void>
打开微信客服
override
openRankList() → Future<void>
打开硬件排行榜
override
openUrl({required String url}) → Future<void>
打开指定网页
override
openWechat() → Future<bool>
打开微信
override
pay({required String appId, required String partnerId, required String prepayId, required String package, required String nonceStr, required String timeStamp, required String sign}) → Future<void>
支付
override
qrauthRespStream() → Stream<WechatQrauthResp>
扫码登录
override
registerApp({required String appId, required String? universalLink}) → Future<void>
向微信注册应用
override
reqStream() → Stream<WechatReq>
override
respStream() → Stream<WechatResp>
override
shareEmoji({required int scene, String? title, String? description, required Uint8List thumbData, Uint8List? emojiData, Uri? emojiUri}) → Future<void>
分享 - Emoji/GIF
override
shareFile({required int scene, String? title, String? description, Uint8List? thumbData, Uint8List? fileData, Uri? fileUri, String? fileExtension}) → Future<void>
分享 - 文件
override
shareImage({required int scene, String? title, String? description, Uint8List? thumbData, Uint8List? imageData, Uri? imageUri}) → Future<void>
分享 - 图片
override
shareMediaMusic({required int scene, String? title, String? description, Uint8List? thumbData, String? musicUrl, String? musicDataUrl, String? musicLowBandUrl, String? musicLowBandDataUrl}) → Future<void>
分享 - 音乐
override
shareMiniProgram({required int scene, String? title, String? description, Uint8List? thumbData, required String webpageUrl, required String userName, String? path, Uint8List? hdImageData, bool withShareTicket = false, int type = WechatMiniProgram.kRelease, bool disableForward = false}) → Future<void>
分享 - 小程序 - 目前只支持分享到会话
override
shareText({required int scene, required String text}) → Future<void>
分享 - 文本
override
shareVideo({required int scene, String? title, String? description, Uint8List? thumbData, String? videoUrl, String? videoLowBandUrl}) → Future<void>
分享 - 视频
override
shareWebpage({required int scene, String? title, String? description, Uint8List? thumbData, required String webpageUrl}) → Future<void>
分享 - 网页
override
startQrauth({required String appId, required List<String> scope, required String noncestr, required String ticket}) → Future<void>
调用微信 API 获得 ticket,开始扫码登录
override
stopQrauth() → Future<void>
暂停扫码登录请求
override
subscribeMsg({required int scene, required String templateId, String? reserved}) → Future<void>
一次性订阅消息
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited